package com.your.company.domain.RoutingPatternProject.code;

import com.ibm.broker.config.appdev.MessageFlow;
import com.ibm.broker.config.appdev.OutputTerminal;
import com.ibm.broker.config.appdev.nodes.MQOutputNode;
import com.ibm.broker.config.appdev.nodes.RouteNode;
import com.ibm.broker.config.appdev.patterns.GeneratePatternInstanceTransform;
import com.ibm.broker.config.appdev.patterns.PatternInstanceManager;
import com.ibm.broker.config.appdev.patterns.PatternParameterRow;
import com.ibm.broker.config.appdev.patterns.PatternParameterTable;

public class MyRoutingJava implements GeneratePatternInstanceTransform {

	@Override
	public void onGeneratePatternInstance(PatternInstanceManager patternInstanceManager) {

		//Get the RoutingFlow.msgflow message flow
		MessageFlow mf1 = patternInstanceManager.getMessageFlow("PatternParameters", "RoutingFlow.msgflow");
		
		//Get the Route Node object
		RouteNode routeNode = (RouteNode) mf1.getNodeByName("Route");
		
		//Get the Parameter Table defined in the Pattern
		PatternParameterTable paramtable = patternInstanceManager.getParameterTable("RoutingTable");
		
		
		Integer outNo;
		
		//Get the "outAmount" parameter (amount of desired outputs
		outNo = Integer.valueOf(patternInstanceManager.getParameterValue("outAmount"));
		
		PatternParameterRow paramTableRow;
		
		//Get the Filter table from the route nodes
		RouteNode.FilterTable filterTable = (RouteNode.FilterTable) routeNode.getFilterTable();
		
		//delete default row in the routeNode filter table
		filterTable.removeRow(filterTable.getRows().get(0));
		
		for(int i=1;i<=outNo;i++){
			
			//Add a row to the Filter Table with the Filter Pattern and Terminal for the current output.
			paramTableRow = paramtable.getRow(i-1);
			RouteNode.FilterTableRow newRow = filterTable.createRow();
			newRow.setFilterPattern(paramTableRow.getValue("filterPattern"));
			newRow.setRoutingOutputTerminal(paramTableRow.getValue("terminal"));
			filterTable.addRow(newRow);
			
			//Create an MQOutput
			MQOutputNode mqOutNode = new MQOutputNode();
				//Set MQOutput node name
			mqOutNode.setNodeName("MQOutput " + i);
				//Set MQOutput node Queue Name
			mqOutNode.setQueueName(patternInstanceManager.getParameterValue("qn"+i));
				//Set MQOutput node Queue Manager
			mqOutNode.setQueueManagerName(patternInstanceManager.getParameterValue("qm"+i));
				//Set location of new node on flow editor
			mqOutNode.setLocation(400,50*i);
			mf1.addNode(mqOutNode);			
			//Add terminal to the Route Node
			OutputTerminal term = routeNode.getOutputTerminal(paramTableRow.getValue("terminal"));
			//Connect Route node to MQOutput node
			mf1.connect(term, mqOutNode.INPUT_TERMINAL_IN);
		}
	}
}
